@@ -31,7 +31,7 @@
 #include <QtCore/QUuid>
 #include <QtCore/QSize>
 #include <QtCore/QProcess>
-#include <QtGui/QWidget>
+#include <QWidget>
 
 // KDE
 #include <KUrl>
@@ -356,6 +356,8 @@ public:
     void saveSession(KConfigGroup& group);
     void restoreSession(KConfigGroup& group);
 
+    void sendSignal(int signal);
+
 public slots:
 
     /**
